Title: [110063] trunk/Source/WebCore
Revision
110063
Author
ad...@apple.com
Date
2012-03-07 09:23:46 -0800 (Wed, 07 Mar 2012)

Log Message

REGRESSION(r96566): Cursor is I-beam upon dragging an attachment in mail
https://bugs.webkit.org/show_bug.cgi?id=80458
<rdar://problem/10873195>

Reviewed by Dan Bernstein.

No tests because we currently don't have any test machinery for cursors.

Make sure the shortcut to always use an iBeam cursor during selection isn't used during dragging.
Before r96566, we handled plugin cursors as a special case before calling into selectCursor, so we never hit this code path.

* page/EventHandler.cpp: (WebCore::EventHandler::selectCursor):

Modified Paths

Diff

Modified: trunk/Source/WebCore/ChangeLog (110062 => 110063)


--- trunk/Source/WebCore/ChangeLog	2012-03-07 17:23:43 UTC (rev 110062)
+++ trunk/Source/WebCore/ChangeLog	2012-03-07 17:23:46 UTC (rev 110063)
@@ -1,3 +1,18 @@
+2012-03-07  Adele Peterson  <ad...@apple.com>
+
+        REGRESSION(r96566): Cursor is I-beam upon dragging an attachment in mail
+        https://bugs.webkit.org/show_bug.cgi?id=80458
+        <rdar://problem/10873195>
+
+        Reviewed by Dan Bernstein.
+
+        No tests because we currently don't have any test machinery for cursors.
+
+        Make sure the shortcut to always use an iBeam cursor during selection isn't used during dragging.
+        Before r96566, we handled plugin cursors as a special case before calling into selectCursor, so we never hit this code path.
+
+        * page/EventHandler.cpp: (WebCore::EventHandler::selectCursor):
+
 2012-03-07  ChangSeok Oh  <shivami...@gmail.com>
 
         [EFL] Key press event is not processed properly.

Modified: trunk/Source/WebCore/page/EventHandler.cpp (110062 => 110063)


--- trunk/Source/WebCore/page/EventHandler.cpp	2012-03-07 17:23:43 UTC (rev 110062)
+++ trunk/Source/WebCore/page/EventHandler.cpp	2012-03-07 17:23:46 UTC (rev 110063)
@@ -1285,8 +1285,8 @@
     const Cursor& iBeam = horizontalText ? iBeamCursor() : verticalTextCursor();
 
     // During selection, use an I-beam no matter what we're over.
-    // If you're capturing mouse events for a particular node, don't treat this as a selection.
-    if (m_mousePressed && m_mouseDownMayStartSelect && m_frame->selection()->isCaretOrRange() && !m_capturingMouseEventsNode)
+    // If a drag may be starting or we're capturing mouse events for a particular node, don't treat this as a selection.
+    if (m_mousePressed && m_mouseDownMayStartSelect && !m_mouseDownMayStartDrag && m_frame->selection()->isCaretOrRange() && !m_capturingMouseEventsNode)
         return iBeam;
 
     if (renderer) {
_______________________________________________
webkit-changes mailing list
webkit-changes@lists.webkit.org
http://lists.webkit.org/mailman/listinfo.cgi/webkit-changes

Reply via email to